.. ref-autoscale

======================
Auto Scaling Reference
======================

boto.ec2.autoscale
------------------

.. automodule:: boto.ec2.autoscale
   :members:   
   :undoc-members:

boto.ec2.autoscale.activity
---------------------------

.. automodule:: boto.ec2.autoscale.activity
   :members:   
   :undoc-members:

boto.ec2.autoscale.group
------------------------

.. automodule:: boto.ec2.autoscale.group
   :members:   
   :undoc-members:


boto.ec2.autoscale.instance
---------------------------

.. automodule:: boto.ec2.autoscale.instance
   :members:   
   :undoc-members:

boto.ec2.autoscale.launchconfig
-------------------------------

.. automodule:: boto.ec2.autoscale.launchconfig
   :members:   
   :undoc-members:

boto.ec2.autoscale.policy
--------------------------

.. automodule:: boto.ec2.autoscale.policy
   :members:   
   :undoc-members:

boto.ec2.autoscale.request
--------------------------

.. automodule:: boto.ec2.autoscale.request
   :members:   
   :undoc-members:

boto.ec2.autoscale.scheduled
----------------------------

.. automodule:: boto.ec2.autoscale.scheduled
   :members:   
   :undoc-members:
